summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorJani Nikula <jani.nikula@intel.com>2026-05-27 13:02:12 +0300
committerJani Nikula <jani.nikula@intel.com>2026-05-28 10:36:31 +0300
commitc1b58e57b4e51fc0efbef02feea5ebf9ba8e0091 (patch)
tree308d8b7a4a946c6cf12b4e3bb66d5259d778e2b0
parent638319d35eb6c0706329c312f2d586b3f56f1c9d (diff)
drm/i915: rename intel_runtime_{suspend, resume} to i915_pm_runtime_{suspend, resume}
All the other struct dev_pm_ops hooks are named i915_pm_*(), but the .runtime_suspend and .runtime_resume hooks are called intel_runtime_suspend() and intel_runtime_resume(), respectively. Rename intel_runtime_suspend() to i915_pm_runtime_suspend() and intel_runtime_resume() to i915_pm_runtime_resume() to unify. Cc: Imre Deak <imre.deak@intel.com> Reviewed-by: Imre Deak <imre.deak@intel.com> Link: https://patch.msgid.link/fc5b796a3fd764a64b257edfdbe08e54b690efbc.1779876087.git.jani.nikula@intel.com Signed-off-by: Jani Nikula <jani.nikula@intel.com>
-rw-r--r--drivers/gpu/drm/i915/i915_driver.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/drivers/gpu/drm/i915/i915_driver.c b/drivers/gpu/drm/i915/i915_driver.c
index d6b94a29c91d..58081b52461a 100644
--- a/drivers/gpu/drm/i915/i915_driver.c
+++ b/drivers/gpu/drm/i915/i915_driver.c
@@ -1558,7 +1558,7 @@ static int i915_pm_restore(struct device *kdev)
return i915_pm_resume(kdev);
}
-static int intel_runtime_suspend(struct device *kdev)
+static int i915_pm_runtime_suspend(struct device *kdev)
{
struct drm_i915_private *dev_priv = kdev_to_i915(kdev);
struct intel_display *display = dev_priv->display;
@@ -1632,7 +1632,7 @@ static int intel_runtime_suspend(struct device *kdev)
if (IS_BROADWELL(dev_priv)) {
/*
* On Broadwell, if we use PCI_D1 the PCH DDI ports will stop
* being detected, and the call we do at intel_runtime_resume()
* won't be able to restore them. Since PCI_D3hot matches the
* actual specification and appears to be working, use it.
*/
@@ -1657,7 +1657,7 @@ static int intel_runtime_suspend(struct device *kdev)
return 0;
}
-static int intel_runtime_resume(struct device *kdev)
+static int i915_pm_runtime_resume(struct device *kdev)
{
struct drm_i915_private *dev_priv = kdev_to_i915(kdev);
struct intel_display *display = dev_priv->display;
@@ -1765,8 +1765,8 @@ const struct dev_pm_ops i915_pm_ops = {
.restore = i915_pm_restore,
/* S0ix (via runtime suspend) event handlers */
- .runtime_suspend = intel_runtime_suspend,
- .runtime_resume = intel_runtime_resume,
+ .runtime_suspend = i915_pm_runtime_suspend,
+ .runtime_resume = i915_pm_runtime_resume,
};
static const struct file_operations i915_driver_fops = {
@@ -1632,7 +1632,7 @@ static int intel_runtime_suspend(struct device *kdev)
/*
* On Broadwell, if we use PCI_D1 the PCH DDI ports will stop
- * being detected, and the call we do at intel_runtime_resume()
+ * being detected, and the call we do at i915_pm_runtime_resume()
* won't be able to restore them. Since PCI_D3hot matches the
* actual specification and appears to be working, use it.